keyvault = {
    "name": "xxxxxxxxx"
    "secret_name": "xxxxxxxxx"
    "tenant_id": "xxxxxxxxx"
    "client_id": "xxxxxxxxx"
    "client_secret": "xxxxxxxxx"
}
auth = {
    "resource_group": "xxxxxxxxx"
    "managed_identity": "xxxxxxxxx"
    "subscription_id": "xxxxxxxxx"
    "tenant_id": "xxxxxxxxx"
    "client_id": "xxxxxxxxx"
    "client_secret": "xxxxxxxxx"
}
blob = {
    "storage_account_name": "xxxxxxxxx"
    "storage_key": "xxxxxxxxx"
    "sas_key": "xxxxxxxxx"
    "container_name": "xxxxxxxxx"
    "path": "xxxxxxxxx"
    "data": "xxxxxxxxx"
}
acr = {
    "resource_group": "xxxxxxxxx"
    "registry_name": "xxxxxxxxx"
    "subscription_id": "xxxxxxxxx"
    "image_name": "xxxxxxxxx"
}
aci = {
    "resource_group": "xxxxxxxxx"
    "container_group_name": "xxxxxxxxx"
    "location": "xxxxxxxxx"
    "subscription_id": "xxxxxxxxx"
}
dls = {
    "dls_name": "xxxxxxxxx"
    "tenant_id": "xxxxxxxxx"
    "client_id": "xxxxxxxxx"
    "client_secret": "xxxxxxxxx"
    "https_proxy": "xxxxxxxxx"
    "path": "xxxxxxxxx"
    "glob_path": "xxxxxxxxx"
    "file_name": "xxxxxxxxx"
    "gz_file_name": "xxxxxxxxx"
    "tmp_file_name": "xxxxxxxxx"
}
